@@ -1,4 +1,5 @@
 # frozen_string_literal: true
+
 module Nokogiri
   module Decorators
     ###
@@ -10,21 +11,21 @@ module Nokogiri
 
       ###
       # look for node with +name+.  See Nokogiri.Slop
-      def method_missing name, *args, &block
+      def method_missing(name, *args, &block)
         if args.empty?
-          list = xpath("#{XPATH_PREFIX}#{name.to_s.sub(/^_/, '')}")
-        elsif args.first.is_a? Hash
+          list = xpath("#{XPATH_PREFIX}#{name.to_s.sub(/^_/, "")}")
+        elsif args.first.is_a?(Hash)
           hash = args.first
           if hash[:css]
             list = css("#{name}#{hash[:css]}")
           elsif hash[:xpath]
-            conds = Array(hash[:xpath]).join(' and ')
+            conds = Array(hash[:xpath]).join(" and ")
             list = xpath("#{XPATH_PREFIX}#{name}[#{conds}]")
           end
         else
           CSS::Parser.without_cache do
             list = xpath(
-              *CSS.xpath_for("#{name}#{args.first}", :prefix => XPATH_PREFIX)
+              *CSS.xpath_for("#{name}#{args.first}", prefix: XPATH_PREFIX)
             )
           end
         end
@@ -33,8 +34,8 @@ module Nokogiri
         list.length == 1 ? list.first : list
       end
 
-      def respond_to_missing? name, include_private = false
-        list = xpath("#{XPATH_PREFIX}#{name.to_s.sub(/^_/, '')}")
+      def respond_to_missing?(name, include_private = false)
+        list = xpath("#{XPATH_PREFIX}#{name.to_s.sub(/^_/, "")}")
 
         !list.empty?
       end
