@@ -1,12 +1,14 @@
 # frozen_string_literal: true
+
 module Nokogiri
   module XML
     class Attr < Node
-      alias :value :content
-      alias :to_s :content
-      alias :content= :value=
+      alias_method :value, :content
+      alias_method :to_s, :content
+      alias_method :content=, :value=
 
       private
+
       def inspect_attributes
         [:name, :namespace, :value]
       end
